@@ -232,6 +232,43 @@ func (t *PrometheusTask) Run() error {
 			return errors.Wrap(err, "reconciling prometheus etcd service monitor secret")
 		}
 	}
+
+	grpcTLS, err := t.factory.GRPCSecret(nil)
+	if err != nil {
+		return errors.Wrap(err, "initializing Prometheus GRPC secret failed")
+	}
+
+	grpcTLS, err = t.client.WaitForSecret(grpcTLS)
+	if err != nil {
+		return errors.Wrap(err, "waiting for Prometheus GRPC secret failed")
+	}
+
+	s, err := t.factory.PrometheusK8sGrpcTLSSecret()
+	if err != nil {
+		return errors.Wrap(err, "error initializing Prometheus Client GRPC TLS secret")
+	}
+
+	s, err = t.factory.HashSecret(s,
+		"ca.crt", string(grpcTLS.Data["ca.crt"]),
+		"server.crt", string(grpcTLS.Data["prometheus-server.crt"]),
+		"server.key", string(grpcTLS.Data["prometheus-server.key"]),
+	)
+	if err != nil {
+		return errors.Wrap(err, "error hashing Prometheus Client GRPC TLS secret")
+	}
+
+	err = t.client.CreateOrUpdateSecret(s)
+	if err != nil {
+		return errors.Wrap(err, "error creating Prometheus Client GRPC TLS secret")
+	}
+
+	err = t.client.DeleteHashedSecret(
+		string(s.Labels["monitoring.openshift.io/hash"]),
+		"prometheus-k8s-grpc-tls",
+	)
+	if err != nil {
+		return errors.Wrap(err, "error creating Prometheus Client GRPC TLS secret")
+	}
 	{
 		// Create trusted CA bundle ConfigMap.
 		trustedCA, err := t.factory.PrometheusK8sTrustedCABundle()
@@ -262,7 +299,7 @@ func (t *PrometheusTask) Run() error {
 		}
 
 		klog.V(4).Info("initializing Prometheus object")
-		p, err := t.factory.PrometheusK8s(host, trustedCA)
+		p, err := t.factory.PrometheusK8s(host, s, trustedCA)
 		if err != nil {
 			return errors.Wrap(err, "initializing Prometheus object failed")
 		}
